<p align=center>
    <img src="image.gif" width="500">
    <img src="https://img.shields.io/circleci/build/github/kkent030315/twitcasting-realtime-chat?style=for-the-badge">
    <img src="https://img.shields.io/pypi/v/twitcasting-realtime-chat?style=for-the-badge">
    <img src="https://img.shields.io/github/license/kkent030315/twitcasting-realtime-chat?style=for-the-badge">
</p>

# twitcasting-realtime-chat
An unofficial comment viewer CLI for TwitCasting lives
